@@ -10,12 +10,14 @@ import (
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
 
+	"github.com/openshift/cluster-svcat-apiserver-operator/pkg/cmd/operator"
+	"github.com/openshift/cluster-svcat-apiserver-operator/pkg/version"
 	utilflag "k8s.io/component-base/cli/flag"
 	"k8s.io/component-base/logs"
-
-	"github.com/openshift/cluster-svcat-apiserver-operator/pkg/cmd/operator"
 )
 
+var versionFlag = goflag.Bool("version", false, "displays source commit info.")
+
 func main() {
 	rand.Seed(time.Now().UTC().UnixNano())
 
@@ -25,11 +27,19 @@ func main() {
 	logs.InitLogs()
 	defer logs.FlushLogs()
 
+	goflag.Parse()
+	if *versionFlag {
+		fmt.Print(version.Commit())
+		// Exit immediately
+		os.Exit(0)
+	}
+
 	command := NewSSCSCommand()
 	if err := command.Execute(); err != nil {
 		fmt.Fprintf(os.Stderr, "%v\n", err)
 		os.Exit(1)
 	}
+
 }
 
 func NewSSCSCommand() *cobra.Command {
